#ifndef GUARD_info_h
#define GUARD_info_h

#ifdef CALIBART
#include<vector>
#else
#include<vector>
#endif

//data
#ifdef CALIBART
class dinfo{
public:
	dinfo() {p=0;n=0;x=0;y=0;}
	size_t p; //number of vars
	size_t n; //number of observations of simulator
	size_t nf; //number of observations of field
	double *x; // jth var of ith obs is *(x+p*i+j)
	double *xf;// jth var of ith field is *(xf+p*i+j)
	double *y; // ith y is *(y+i) or y[i]
	double *yf;// ith yf is *(yf+i) or yf[i]
};
#else
class dinfo {
public:
   dinfo() {p=0;n=0;x=0;y=0;}
   size_t p;  //number of vars
   size_t n;  //number of observations
   double *x; // jth var of ith obs is *(x + p*i+j)
   double *y; // ith y is *(y+i) or y[i]
};
#endif

//prior and mcmc
#ifdef CALIBART
class pinfo
{
public:
	pinfo() {pertalpha=0.10;pbd=1.0;pb=.5;alpha=.95;beta=.5;sigma=1.0;tau0=1.0;tauc=1.0;taud=1.0;sigmaf=1.0;ncaldims=0;taccept=0;tavgd=0;tmaxd=0;}
   double pertalpha; //alpha for scaling pert proposal
//mcmc info
	double pbd; //prob of birth/death
	double pb;  //prob of birth
//prior info
	double alpha;
	double beta;
	double tau0; //overall s.d.
	double tauc; //s.d. for simulator outputs
	double taud; //s.d. for discrepancy
	double mu0;  //overall mean
	double muc;  //mean for simulator outputs
	double mud;  //mean for discrepancy
//sigma
	double sigma;
	double sigmaf;
//calibration param
	unsigned int ncaldims;                // Unlike the other variables in the pinfo structure, the variables
	std::vector<unsigned int> caldims;    // associated with the calibration parameters MUST be always up to
                                          // date and 
	std::vector<double> calests;          // in sync across the master AND slave nodes.  The other vars are only 
                                          // guaranteed
                                          // to be correct on the master node.
	std::vector<size_t> calacc;           // Number of accepts of proposals
	std::vector<double> calpropscale;     // scale variance of normal proposal distribution
	unsigned int imdim;   // which covariate is the model/field indicator variable Im?
   	std::vector< std::vector<double> > cvpm;  // Change of variable proposal probability matrix
	unsigned int taccept; //acceptance count of tree proposals
	unsigned int tproposal; //number of tree proposals
	unsigned int tavgd; //average tree depth
	unsigned int tmaxd; //maximum tree depth
};
#else
class pinfo
{
public:
   pinfo() {pbd=1.0;pb=.5;alpha=.95;beta=.5;tau=1.0;sigma=1.0;taccept=0;tavgd=0;tmaxd=0;}
//mcmc info
   double pbd; //prob of birth/death
   double pb;  //prob of birth
//prior info
   double alpha;
   double beta;
   double tau;
//sigma
   double sigma;
   std::vector< std::vector<double> > cvpm;  // Change of variable proposal probability matrix
   unsigned int taccept; //acceptance count of tree proposals
   unsigned int tproposal; //number of tree proposals
   unsigned int tavgd; //average tree depth
   unsigned int tmaxd; //maximum tree depth
};
#endif

//sufficient statistics for 1 node
#ifdef CALIBART
class sinfo
{
public:
	sinfo() {n=0;sy=0.0;sy2=0.0;nf=0;sf=0.0;sf2=0.0;}
	size_t n;
	size_t nf;
	double sy;
	double sf;
	double sy2;
	double sf2;
};
#else
class sinfo
{
public:
   sinfo() {n=0;sy=0.0;sy2=0.0;}
   size_t n;
   double sy;
   double sy2;
};
#endif

#endif
